@@ -1,36 +1,32 @@
 "use strict";
 
+var _commander = require("commander");
+
+var _module = _interopRequireWildcard(require("module"), true);
+
 var _util = require("util");
 
-var babel = _interopRequireWildcard(require("@babel/core"));
+var _path = require("path");
+
+var _repl = require("repl");
+
+var babel = require("@babel/core");
+
+var _vm = require("vm");
 
 require("core-js/stable");
 
 require("regenerator-runtime/runtime");
 
-var _register = _interopRequireDefault(require("@babel/register"));
+var _register = require("@babel/register");
 
 var _url = require("url");
 
-var _module = require("module");
+function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
 
-function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
+function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
 
-function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }
-
-function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
-
-const commander = require("commander");
-
-const Module = require("module");
-
-const path = require("path");
-
-const repl = require("repl");
-
-const vm = require("vm");
-
-const program = new commander.Command("babel-node");
+const program = new _commander.Command("babel-node");
 
 function collect(value, previousValue) {
   if (typeof value !== "string") return previousValue;
@@ -50,7 +46,7 @@ program.option("--env-name [name]", "The name of the 'env' to use when loading c
 program.option("--root-mode [mode]", "The project-root resolution mode. " + "One of 'root' (the default), 'upward', or 'upward-optional'.");
 program.option("-w, --plugins [string]", "", collect);
 program.option("-b, --presets [string]", "", collect);
-program.version("7.13.10");
+program.version("7.14.7");
 program.usage("[options] [ -e script | script.js ] [arguments]");
 program.parse(process.argv);
 const babelOptions = {
@@ -106,7 +102,7 @@ const _eval = function (code, filename) {
     presets: program.presets,
     plugins: (program.plugins || []).concat([replPlugin])
   }).code;
-  return vm.runInThisContext(code, {
+  return _vm.runInThisContext(code, {
     filename: filename
   });
 };
@@ -116,9 +112,9 @@ if (program.eval || program.print) {
   if (!code || code === true) code = program.print;
   global.__filename = "[eval]";
   global.__dirname = process.cwd();
-  const module = new Module(global.__filename);
+  const module = new _module.default(global.__filename);
   module.filename = global.__filename;
-  module.paths = Module._nodeModulePaths(global.__dirname);
+  module.paths = _module.default._nodeModulePaths(global.__dirname);
   global.exports = module.exports;
   global.module = module;
   global.require = module.require.bind(module);
@@ -164,13 +160,14 @@ if (program.eval || program.print) {
     requireArgs();
     const filename = args[0];
 
-    if (!path.isAbsolute(filename)) {
-      args[0] = path.join(process.cwd(), filename);
+    if (!_path.isAbsolute(filename)) {
+      args[0] = _path.join(process.cwd(), filename);
     }
 
     process.argv = ["node"].concat(args);
     process.execArgv.push(__filename);
-    Module.runMain();
+
+    _module.default.runMain();
   } else {
     requireArgs();
     replStart();
@@ -195,7 +192,7 @@ function requireArgs() {
 }
 
 function replStart() {
-  const replServer = repl.start({
+  const replServer = _repl.start({
     prompt: "babel > ",
     input: process.stdin,
     output: process.stdout,
@@ -203,6 +200,7 @@ function replStart() {
     useGlobal: true,
     preview: true
   });
+
   {
     replServer.setupHistory == null ? void 0 : replServer.setupHistory(process.env.NODE_REPL_HISTORY, () => {});
   }
